## Using this Adapter

The `adapter.js` file contains the calls the adapter makes available to the rest of the Itential Platform. The API detailed for these calls should be available through JSDOC. The following is a brief summary of the calls.

### Generic Adapter Calls

These are adapter methods that IAP or you might use. There are some other methods not shown here that might be used for internal adapter functionality.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">connect()</td>
    <td style="padding:15px">This call is run when the Adapter is first loaded by he Itential Platform. It validates the properties have been provided correctly.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">healthCheck(callback)</td>
    <td style="padding:15px">This call ensures that the adapter can communicate with Adapter for GitHub System. The actual call that is used is defined in the adapter properties and .system entities action.json file.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">refreshProperties(properties)</td>
    <td style="padding:15px">This call provides the adapter the ability to accept property changes without having to restart the adapter.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">encryptProperty(property, technique, callback)</td>
    <td style="padding:15px">This call will take the provided property and technique, and return the property encrypted with the technique. This allows the property to be used in the adapterProps section for the credential password so that the password does not have to be in clear text. The adapter will decrypt the property as needed for communications with Adapter for GitHub System.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">iapUpdateAdapterConfiguration(configFile, changes, entity, type, action, callback)</td>
    <td style="padding:15px">This call provides the ability to update the adapter configuration from IAP - includes actions, schema, mockdata and other configurations.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapSuspendAdapter(mode, callback)</td>
    <td style="padding:15px">This call provides the ability to suspend the adapter and either have requests rejected or put into a queue to be processed after the adapter is resumed.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapUnsuspendAdapter(callback)</td>
    <td style="padding:15px">This call provides the ability to resume a suspended adapter. Any requests in queue will be processed before new requests.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapGetAdapterQueue(callback)</td>
    <td style="padding:15px">This call will return the requests that are waiting in the queue if throttling is enabled.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapFindAdapterPath(apiPath, callback)</td>
    <td style="padding:15px">This call provides the ability to see if a particular API path is supported by the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapTroubleshootAdapter(props, persistFlag, adapter, callback)</td>
    <td style="padding:15px">This call can be used to check on the performance of the adapter - it checks connectivity, healthcheck and basic get calls.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterHealthcheck(adapter, callback)</td>
    <td style="padding:15px">This call will return the results of a healthcheck.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterConnectivity(callback)</td>
    <td style="padding:15px">This call will return the results of a connectivity check.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterBasicGet(callback)</td>
    <td style="padding:15px">This call will return the results of running basic get API calls.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapMoveAdapterEntitiesToDB(callback)</td>
    <td style="padding:15px">This call will push the adapter configuration from the entities directory into the Adapter or IAP Database.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapDeactivateTasks(tasks, callback)</td>
    <td style="padding:15px">This call provides the ability to remove tasks from the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapActivateTasks(tasks, callback)</td>
    <td style="padding:15px">This call provides the ability to add deactivated tasks back into the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapExpandedGenericAdapterRequest(metadata, uriPath, restMethod, pathVars, queryData, requestBody, addlHeaders, callback)</td>
    <td style="padding:15px">This is an expanded Generic Call. The metadata object allows us to provide many new capabilities within the generic request.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">genericAdapterRequest(uriPath, restMethod, queryData, requestBody, addlHeaders, callback)</td>
    <td style="padding:15px">This call allows you to provide the path to have the adapter call. It is an easy way to incorporate paths that have not been built into the adapter yet.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">genericAdapterRequestNoBasePath(uriPath, restMethod, queryData, requestBody, addlHeaders, callback)</td>
    <td style="padding:15px">This call is the same as the genericAdapterRequest only it does not add a base_path or version to the call.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterLint(callback)</td>
    <td style="padding:15px">Runs lint on the addapter and provides the information back.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRunAdapterTests(callback)</td>
    <td style="padding:15px">Runs baseunit and unit tests on the adapter and provides the information back.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapGetAdapterInventory(callback)</td>
    <td style="padding:15px">This call provides some inventory related information about the adapter.</td>
    <td style="padding:15px">Yes</td>
  </tr>
</table>
<br>
  
### Adapter Cache Calls

These are adapter methods that are used for adapter caching. If configured, the adapter will cache based on the interval provided. However, you can force a population of the cache manually as well.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">iapPopulateEntityCache(entityTypes, callback)</td>
    <td style="padding:15px">This call populates the adapter cache.</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">iapRetrieveEntitiesCache(entityType, options, callback)</td>
    <td style="padding:15px">This call retrieves the specific items from the adapter cache.</td>
    <td style="padding:15px">Yes</td>
  </tr>
</table>
<br>
  
### Adapter Broker Calls

These are adapter methods that are used to integrate to IAP Brokers. This adapter currently supports the following broker calls.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">hasEntities(entityType, entityList, callback)</td>
    <td style="padding:15px">This call is utilized by the IAP Device Broker to determine if the adapter has a specific entity and item of the entity.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">getDevice(deviceName, callback)</td>
    <td style="padding:15px">This call returns the details of the requested device.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">getDevicesFiltered(options, callback)</td>
    <td style="padding:15px">This call returns the list of devices that match the criteria provided in the options filter.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">isAlive(deviceName, callback)</td>
    <td style="padding:15px">This call returns whether the device status is active</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">getConfig(deviceName, format, callback)</td>
    <td style="padding:15px">This call returns the configuration for the selected device.</td>
    <td style="padding:15px">No</td>
  </tr>
  <tr>
    <td style="padding:15px">iapGetDeviceCount(callback)</td>
    <td style="padding:15px">This call returns the count of devices.</td>
    <td style="padding:15px">No</td>
  </tr>
</table>
<br>

### Specific Adapter Calls

Specific adapter calls are built based on the API of the GitHub System. The Adapter Builder creates the proper method comments for generating JS-DOC for the adapter. This is the best way to get information on the calls.

<table border="1" class="bordered-table">
  <tr>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Method Signature</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Description</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Path</span></th>
    <th bgcolor="lightgrey" style="padding:15px"><span style="font-size:12.0pt">Workflow?</span></th>
  </tr>
  <tr>
    <td style="padding:15px">getEmojis(callback)</td>
    <td style="padding:15px">Lists all the emojis available to use on GitHub.</td>
    <td style="padding:15px">{base_path}/{version}/emojis?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getEvents(callback)</td>
    <td style="padding:15px">List public events.</td>
    <td style="padding:15px">{base_path}/{version}/events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getFeeds(callback)</td>
    <td style="padding:15px">List Feeds.
GitHub provides several timeline resources in Atom format. The Feeds API
 lists all the feeds available to the authenticating user.</td>
    <td style="padding:15px">{base_path}/{version}/feeds?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGists(since, callback)</td>
    <td style="padding:15px">List the authenticated user's gists or if called anonymously, this will
return all public gists.</td>
    <td style="padding:15px">{base_path}/{version}/gists?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postGists(body, callback)</td>
    <td style="padding:15px">Create a gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGistsPublic(since, callback)</td>
    <td style="padding:15px">List all public gists.</td>
    <td style="padding:15px">{base_path}/{version}/gists/public?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGistsStarred(since, callback)</td>
    <td style="padding:15px">List the authenticated user's starred gists.</td>
    <td style="padding:15px">{base_path}/{version}/gists/starred?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteGistsId(id, callback)</td>
    <td style="padding:15px">Delete a gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGistsId(id, callback)</td>
    <td style="padding:15px">Get a single gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchGistsId(id, body, callback)</td>
    <td style="padding:15px">Edit a gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGistsIdComments(id, callback)</td>
    <td style="padding:15px">List comments on a gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postGistsIdComments(id, body, callback)</td>
    <td style="padding:15px">Create a commen</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteGistsIdCommentsCommentId(id, commentId, callback)</td>
    <td style="padding:15px">Delete a comment.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/comments/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGistsIdCommentsCommentId(id, commentId, callback)</td>
    <td style="padding:15px">Get a single comment.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/comments/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchGistsIdCommentsCommentId(id, commentId, body, callback)</td>
    <td style="padding:15px">Edit a comment.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/comments/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postGistsIdForks(id, callback)</td>
    <td style="padding:15px">Fork a gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/forks?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteGistsIdStar(id, callback)</td>
    <td style="padding:15px">Unstar a gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/star?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGistsIdStar(id, callback)</td>
    <td style="padding:15px">Check if a gist is starred.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/star?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putGistsIdStar(id, callback)</td>
    <td style="padding:15px">Star a gist.</td>
    <td style="padding:15px">{base_path}/{version}/gists/{pathv1}/star?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGitignoreTemplates(callback)</td>
    <td style="padding:15px">Listing available templates.
List all templates available to pass as an option when creating a repository.</td>
    <td style="padding:15px">{base_path}/{version}/gitignore/templates?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getGitignoreTemplatesLanguage(language, callback)</td>
    <td style="padding:15px">Get a single template.</td>
    <td style="padding:15px">{base_path}/{version}/gitignore/templates/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getIssues(filter = 'assigned', state = 'open', labels, sort = 'created', direction = 'asc', since, callback)</td>
    <td style="padding:15px">List issues.
List all issues across all the authenticated user's visible repositories.</td>
    <td style="padding:15px">{base_path}/{version}/issues?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getLegacyIssuesSearchOwnerRepositoryStateKeyword(keyword, state = 'open', owner, repository, callback)</td>
    <td style="padding:15px">Find issues by state and keyword.</td>
    <td style="padding:15px">{base_path}/{version}/legacy/issues/search/{pathv1}/{pathv2}/{pathv3}/{pathv4}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getLegacyReposSearchKeyword(keyword, order = 'desc', language, startPage, sort = 'updated', callback)</td>
    <td style="padding:15px">Find repositories by keyword. Note, this legacy method does not follow the v3 pagination pattern. This method returns up to 100 results per page and pages can be fetched using the start_page parameter.</td>
    <td style="padding:15px">{base_path}/{version}/legacy/repos/search/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getLegacyUserEmailEmail(email, callback)</td>
    <td style="padding:15px">This API call is added for compatibility reasons only.</td>
    <td style="padding:15px">{base_path}/{version}/legacy/user/email/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getLegacyUserSearchKeyword(keyword, order = 'desc', startPage, sort = 'updated', callback)</td>
    <td style="padding:15px">Find users by keyword.</td>
    <td style="padding:15px">{base_path}/{version}/legacy/user/search/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postMarkdown(body, callback)</td>
    <td style="padding:15px">Render an arbitrary Markdown document</td>
    <td style="padding:15px">{base_path}/{version}/markdown?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postMarkdownRaw(callback)</td>
    <td style="padding:15px">Render a Markdown document in raw mode</td>
    <td style="padding:15px">{base_path}/{version}/markdown/raw?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getMeta(callback)</td>
    <td style="padding:15px">This gives some information about GitHub.com, the service.</td>
    <td style="padding:15px">{base_path}/{version}/meta?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getNetworksOwnerRepoEvents(owner, repo, callback)</td>
    <td style="padding:15px">List public events for a network of repositories.</td>
    <td style="padding:15px">{base_path}/{version}/networks/{pathv1}/{pathv2}/events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getNotifications(all, participating, since, callback)</td>
    <td style="padding:15px">List your notifications.
List all notifications for the current user, grouped by repository.</td>
    <td style="padding:15px">{base_path}/{version}/notifications?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putNotifications(body, callback)</td>
    <td style="padding:15px">Mark as read.
Marking a notification as "read" removes it from the default view on GitHub.com.</td>
    <td style="padding:15px">{base_path}/{version}/notifications?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getNotificationsThreadsId(id, callback)</td>
    <td style="padding:15px">View a single thread.</td>
    <td style="padding:15px">{base_path}/{version}/notifications/threads/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchNotificationsThreadsId(id, callback)</td>
    <td style="padding:15px">Mark a thread as read</td>
    <td style="padding:15px">{base_path}/{version}/notifications/threads/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteNotificationsThreadsIdSubscription(id, callback)</td>
    <td style="padding:15px">Delete a Thread Subscription.</td>
    <td style="padding:15px">{base_path}/{version}/notifications/threads/{pathv1}/subscription?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getNotificationsThreadsIdSubscription(id, callback)</td>
    <td style="padding:15px">Get a Thread Subscription.</td>
    <td style="padding:15px">{base_path}/{version}/notifications/threads/{pathv1}/subscription?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putNotificationsThreadsIdSubscription(id, body, callback)</td>
    <td style="padding:15px">Set a Thread Subscription.
This lets you subscribe to a thread, or ignore it. Subscribing to a thread
is unnecessary if the user is already subscribed to the repository. Ignoring
a thread will mute all future notifications (until you comment or get @mentioned).</td>
    <td style="padding:15px">{base_path}/{version}/notifications/threads/{pathv1}/subscription?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrg(org, callback)</td>
    <td style="padding:15px">Get an Organization.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchOrgsOrg(org, body, callback)</td>
    <td style="padding:15px">Edit an Organization.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgEvents(org, callback)</td>
    <td style="padding:15px">List public events for an organization.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgIssues(org, filter = 'assigned', state = 'open', labels, sort = 'created', direction = 'asc', since, callback)</td>
    <td style="padding:15px">List issues.
List all issues for a given organization for the authenticated user.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/issues?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgMembers(org, callback)</td>
    <td style="padding:15px">Members list.
List all users who are members of an organization. A member is a user tha
belongs to at least 1 team in the organization. If the authenticated user
is also an owner of this organization then both concealed and public members
will be returned. If the requester is not an owner of the organization the
query will be redirected to the public members list.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/members?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteOrgsOrgMembersUsername(org, username, callback)</td>
    <td style="padding:15px">Remove a member.
Removing a user from this list will remove them from all teams and they
will no longer have any access to the organization's repositories.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgMembersUsername(org, username, callback)</td>
    <td style="padding:15px">Check if a user is, publicly or privately, a member of the organization.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgPublicMembers(org, callback)</td>
    <td style="padding:15px">Public members list.
Members of an organization can choose to have their membership publicized
or not.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/public_members?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteOrgsOrgPublicMembersUsername(org, username, callback)</td>
    <td style="padding:15px">Conceal a user's membership.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/public_members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgPublicMembersUsername(org, username, callback)</td>
    <td style="padding:15px">Check public membership.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/public_members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putOrgsOrgPublicMembersUsername(org, username, callback)</td>
    <td style="padding:15px">Publicize a user's membership.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/public_members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgRepos(org, type = 'all', callback)</td>
    <td style="padding:15px">List repositories for the specified org.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/repos?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postOrgsOrgRepos(org, body, callback)</td>
    <td style="padding:15px">Create a new repository for the authenticated user. OAuth users must supply
repo scope.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/repos?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getOrgsOrgTeams(org, callback)</td>
    <td style="padding:15px">List teams.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/teams?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postOrgsOrgTeams(org, body, callback)</td>
    <td style="padding:15px">Create team.
In order to create a team, the authenticated user must be an owner of organization.</td>
    <td style="padding:15px">{base_path}/{version}/orgs/{pathv1}/teams?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getRateLimit(callback)</td>
    <td style="padding:15px">Get your current rate limit status
Note: Accessing this endpoint does not count against your rate limit.</td>
    <td style="padding:15px">{base_path}/{version}/rate_limit?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Delete a Repository.
Deleting a repository requires admin access. If OAuth is used, the delete_repo
scope is required.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Get repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepo(owner, repo, body, callback)</td>
    <td style="padding:15px">Edit repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoAssignees(owner, repo, callback)</td>
    <td style="padding:15px">List assignees.
This call lists all the available assignees (owner + collaborators) to which
issues may be assigned.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/assignees?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoAssigneesAssignee(owner, repo, assignee, callback)</td>
    <td style="padding:15px">Check assignee.
You may also check to see if a particular user is an assignee for a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/assignees/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoBranches(owner, repo, callback)</td>
    <td style="padding:15px">Get list of branches</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/branches?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoBranchesBranch(owner, repo, branch, callback)</td>
    <td style="padding:15px">Get Branch</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/branches/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCollaborators(owner, repo, callback)</td>
    <td style="padding:15px">List.
When authenticating as an organization owner of an organization-owned
repository, all organization owners are included in the list of
collaborators. Otherwise, only users with access to the repository are
returned in the collaborators list.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/collaborators?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoCollaboratorsUser(owner, repo, user, callback)</td>
    <td style="padding:15px">Remove collaborator.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/collaborators/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCollaboratorsUser(owner, repo, user, callback)</td>
    <td style="padding:15px">Check if user is a collaborator</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/collaborators/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putReposOwnerRepoCollaboratorsUser(owner, repo, user, callback)</td>
    <td style="padding:15px">Add collaborator.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/collaborators/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoComments(owner, repo, callback)</td>
    <td style="padding:15px">List commit comments for a repository.
Comments are ordered by ascending ID.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoCommentsCommentId(owner, repo, commentId, callback)</td>
    <td style="padding:15px">Delete a commit comment</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCommentsCommentId(owner, repo, commentId, callback)</td>
    <td style="padding:15px">Get a single commit comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoCommentsCommentId(owner, repo, commentId, body, callback)</td>
    <td style="padding:15px">Update a commit comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCommits(owner, repo, since, sha, pathParam, author, until, callback)</td>
    <td style="padding:15px">List commits on a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/commits?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCommitsRefStatus(owner, repo, ref, callback)</td>
    <td style="padding:15px">Get the combined Status for a specific Ref
The Combined status endpoint is currently available for developers to preview. During the preview period, the API may change without advance notice. Please see the blog post for full details.
To access this endpoint during the preview period, you must provide a custom media type in the Accept header:
application/vnd.github.she-hulk-preview+json</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/commits/{pathv3}/status?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCommitsShaCode(owner, repo, shaCode, callback)</td>
    <td style="padding:15px">Get a single commit.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/commits/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCommitsShaCodeComments(owner, repo, shaCode, callback)</td>
    <td style="padding:15px">List comments for a single commitList comments for a single commit.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/commits/{pathv3}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoCommitsShaCodeComments(owner, repo, shaCode, body, callback)</td>
    <td style="padding:15px">Create a commit comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/commits/{pathv3}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoCompareBaseIdHeadId(owner, repo, baseId, headId, callback)</td>
    <td style="padding:15px">Compare two commits</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/compare/{pathv3}...{pathv4}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoContentsPath(owner, repo, pathParam, body, callback)</td>
    <td style="padding:15px">Delete a file.
This method deletes a file in a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/contents/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoContentsPath(owner, repo, pathParam, pathParamQuery, ref, callback)</td>
    <td style="padding:15px">Get contents.
This method returns the contents of a file or directory in a repository.
Files and symlinks support a custom media type for getting the raw content.
Directories and submodules do not support custom media types.
Note: This API supports files up to 1 megabyte in size.
Here can be many outcomes. For details see "http://developer.github.com/v3/repos/contents/"</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/contents/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putReposOwnerRepoContentsPath(owner, repo, pathParam, body, callback)</td>
    <td style="padding:15px">Create a file.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/contents/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoContributors(owner, repo, anon, callback)</td>
    <td style="padding:15px">Get list of contributors.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/contributors?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoDeployments(owner, repo, callback)</td>
    <td style="padding:15px">Users with pull access can view deployments for a repository</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/deployments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoDeployments(owner, repo, body, callback)</td>
    <td style="padding:15px">Users with push access can create a deployment for a given ref</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/deployments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoDeploymentsIdStatuses(owner, repo, id, callback)</td>
    <td style="padding:15px">Users with pull access can view deployment statuses for a deployment</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/deployments/{pathv3}/statuses?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoDeploymentsIdStatuses(owner, repo, id, body, callback)</td>
    <td style="padding:15px">Create a Deployment Status
Users with push access can create deployment statuses for a given deployment:</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/deployments/{pathv3}/statuses?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoDownloads(owner, repo, callback)</td>
    <td style="padding:15px">Deprecated. List downloads for a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/downloads?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoDownloadsDownloadId(owner, repo, downloadId, callback)</td>
    <td style="padding:15px">Deprecated. Delete a download.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/downloads/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoDownloadsDownloadId(owner, repo, downloadId, callback)</td>
    <td style="padding:15px">Deprecated. Get a single download.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/downloads/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoEvents(owner, repo, callback)</td>
    <td style="padding:15px">Get list of repository events.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoForks(owner, repo, sort = 'newes', callback)</td>
    <td style="padding:15px">List forks.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/forks?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoForks(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a fork.
Forking a Repository happens asynchronously. Therefore, you may have to wai
a short period before accessing the git objects. If this takes longer than 5
minutes, be sure to contact Support.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/forks?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoGitBlobs(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a Blob.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/blobs?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoGitBlobsShaCode(owner, repo, shaCode, callback)</td>
    <td style="padding:15px">Get a Blob.
Since blobs can be any arbitrary binary data, the input and responses for
the blob API takes an encoding parameter that can be either utf-8 or
base64. If your data cannot be losslessly sent as a UTF-8 string, you can
base64 encode it.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/blobs/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoGitCommits(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a Commit.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/commits?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoGitCommitsShaCode(owner, repo, shaCode, callback)</td>
    <td style="padding:15px">Get a Commit.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/commits/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoGitRefs(owner, repo, callback)</td>
    <td style="padding:15px">Get all References</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/refs?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoGitRefs(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a Reference</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/refs?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoGitRefsRef(owner, repo, ref, callback)</td>
    <td style="padding:15px">Delete a Reference
Example: Deleting a branch: DELETE /repos/octocat/Hello-World/git/refs/heads/feature-a
Example: Deleting a tag:        DELETE /repos/octocat/Hello-World/git/refs/tags/v1.0</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/refs/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoGitMatchingRefs(owner, repo, ref, callback)</td>
    <td style="padding:15px">Get all Matching References</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/matching-refs/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoGitRefsRef(owner, repo, ref, callback)</td>
    <td style="padding:15px">Get a Reference</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/refs/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoGitRefsRef(owner, repo, ref, body, callback)</td>
    <td style="padding:15px">Update a Reference</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/refs/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoGitTags(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a Tag Object.
Note that creating a tag object does not create the reference that makes a
tag in Git. If you want to create an annotated tag in Git, you have to do
this call to create the tag object, and then create the refs/tags/[tag]
reference. If you want to create a lightweight tag, you only have to create
the tag reference - this call would be unnecessary.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/tags?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoGitTagsShaCode(owner, repo, shaCode, callback)</td>
    <td style="padding:15px">Get a Tag.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/tags/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoGitTrees(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a Tree.
The tree creation API will take nested entries as well. If both a tree and
a nested path modifying that tree are specified, it will overwrite the
contents of that tree with the new path contents and write a new tree out.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/trees?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoGitTreesShaCode(owner, repo, shaCode, recursive, callback)</td>
    <td style="padding:15px">Get a Tree.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/git/trees/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoHooks(owner, repo, callback)</td>
    <td style="padding:15px">Get list of hooks.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/hooks?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoHooks(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a hook.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/hooks?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoHooksHookId(owner, repo, hookId, callback)</td>
    <td style="padding:15px">Delete a hook.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/hooks/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoHooksHookId(owner, repo, hookId, callback)</td>
    <td style="padding:15px">Get single hook.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/hooks/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoHooksHookId(owner, repo, hookId, body, callback)</td>
    <td style="padding:15px">Edit a hook.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/hooks/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoHooksHookIdTests(owner, repo, hookId, callback)</td>
    <td style="padding:15px">Test a push hook.
This will trigger the hook with the latest push to the current repository
if the hook is subscribed to push events. If the hook is not subscribed
to push events, the server will respond with 204 but no test POST will
be generated.
Note: Previously /repos/:owner/:repo/hooks/:id/tes</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/hooks/{pathv3}/tests?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssues(owner, repo, filter = 'assigned', state = 'open', labels, sort = 'created', direction = 'asc', since, callback)</td>
    <td style="padding:15px">List issues for a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoIssues(owner, repo, body, callback)</td>
    <td style="padding:15px">Create an issue.
Any user with pull access to a repository can create an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesComments(owner, repo, direction, sort = 'created', since, callback)</td>
    <td style="padding:15px">List comments in a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoIssuesCommentsCommentId(owner, repo, commentId, callback)</td>
    <td style="padding:15px">Delete a comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesCommentsCommentId(owner, repo, commentId, callback)</td>
    <td style="padding:15px">Get a single comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoIssuesCommentsCommentId(owner, repo, commentId, body, callback)</td>
    <td style="padding:15px">Edit a comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesEvents(owner, repo, callback)</td>
    <td style="padding:15px">List issue events for a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesEventsEventId(owner, repo, eventId, callback)</td>
    <td style="padding:15px">Get a single event.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/events/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesNumber(owner, repo, number, callback)</td>
    <td style="padding:15px">Get a single issue</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoIssuesNumber(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Edit an issue.
Issue owners and users with push access can edit an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesNumberComments(owner, repo, number, callback)</td>
    <td style="padding:15px">List comments on an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoIssuesNumberComments(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Create a comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesNumberEvents(owner, repo, number, callback)</td>
    <td style="padding:15px">List events for an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoIssuesNumberLabels(owner, repo, number, callback)</td>
    <td style="padding:15px">Remove all labels from an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/labels?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoIssuesNumberLabels(owner, repo, number, callback)</td>
    <td style="padding:15px">List labels on an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/labels?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoIssuesNumberLabels(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Add labels to an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/labels?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putReposOwnerRepoIssuesNumberLabels(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Replace all labels for an issue.
Sending an empty array ([]) will remove all Labels from the Issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/labels?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoIssuesNumberLabelsName(owner, repo, number, name, callback)</td>
    <td style="padding:15px">Remove a label from an issue.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/issues/{pathv3}/labels/{pathv4}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoKeys(owner, repo, callback)</td>
    <td style="padding:15px">Get list of keys.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/keys?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoKeys(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a key.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/keys?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoKeysKeyId(owner, repo, keyId, callback)</td>
    <td style="padding:15px">Delete a key.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/keys/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoKeysKeyId(owner, repo, keyId, callback)</td>
    <td style="padding:15px">Get a key</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/keys/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoLabels(owner, repo, callback)</td>
    <td style="padding:15px">List all labels for this repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/labels?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoLabels(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a label.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/labels?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoLabelsName(owner, repo, name, callback)</td>
    <td style="padding:15px">Delete a label.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/labels/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoLabelsName(owner, repo, name, callback)</td>
    <td style="padding:15px">Get a single label.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/labels/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoLabelsName(owner, repo, name, body, callback)</td>
    <td style="padding:15px">Update a label.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/labels/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoLanguages(owner, repo, callback)</td>
    <td style="padding:15px">List languages.
List languages for the specified repository. The value on the right of a
language is the number of bytes of code written in that language.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/languages?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoMerges(owner, repo, body, callback)</td>
    <td style="padding:15px">Perform a merge.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/merges?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoMilestones(owner, repo, state = 'open', direction, sort = 'due_date', callback)</td>
    <td style="padding:15px">List milestones for a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/milestones?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoMilestones(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a milestone.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/milestones?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoMilestonesNumber(owner, repo, number, callback)</td>
    <td style="padding:15px">Delete a milestone.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/milestones/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoMilestonesNumber(owner, repo, number, callback)</td>
    <td style="padding:15px">Get a single milestone.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/milestones/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoMilestonesNumber(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Update a milestone.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/milestones/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoMilestonesNumberLabels(owner, repo, number, callback)</td>
    <td style="padding:15px">Get labels for every issue in a milestone.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/milestones/{pathv3}/labels?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoNotifications(owner, repo, all, participating, since, callback)</td>
    <td style="padding:15px">List your notifications in a repository
List all notifications for the current user.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/notifications?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putReposOwnerRepoNotifications(owner, repo, body, callback)</td>
    <td style="padding:15px">Mark notifications as read in a repository.
Marking all notifications in a repository as "read" removes them from the
default view on GitHub.com.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/notifications?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPulls(owner, repo, state = 'open', head, base, callback)</td>
    <td style="padding:15px">List pull requests.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoPulls(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a pull request.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPullsComments(owner, repo, direction, sort = 'created', since, callback)</td>
    <td style="padding:15px">List comments in a repository.
By default, Review Comments are ordered by ascending ID.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoPullsCommentsCommentId(owner, repo, commentId, callback)</td>
    <td style="padding:15px">Delete a comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPullsCommentsCommentId(owner, repo, commentId, callback)</td>
    <td style="padding:15px">Get a single comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoPullsCommentsCommentId(owner, repo, commentId, body, callback)</td>
    <td style="padding:15px">Edit a comment.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/comments/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPullsNumber(owner, repo, number, callback)</td>
    <td style="padding:15px">Get a single pull request.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoPullsNumber(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Update a pull request.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPullsNumberComments(owner, repo, number, callback)</td>
    <td style="padding:15px">List comments on a pull request.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoPullsNumberComments(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Create a comment.
  #TODO Alternative input ( http://developer.github.com/v3/pulls/comments/ )
  description: |
    Alternative Input.
    Instead of passing commit_id, path, and position you can reply to an
    existing Pull Request Comment like this:

        body
           Required string
        in_reply_to
           Required number - Comment id to reply to.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}/comments?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPullsNumberCommits(owner, repo, number, callback)</td>
    <td style="padding:15px">List commits on a pull request.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}/commits?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPullsNumberFiles(owner, repo, number, callback)</td>
    <td style="padding:15px">List pull requests files.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}/files?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoPullsNumberMerge(owner, repo, number, callback)</td>
    <td style="padding:15px">Get if a pull request has been merged.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}/merge?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putReposOwnerRepoPullsNumberMerge(owner, repo, number, body, callback)</td>
    <td style="padding:15px">Merge a pull request (Merge Button's)</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/pulls/{pathv3}/merge?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoReadme(owner, repo, ref, callback)</td>
    <td style="padding:15px">Get the README.
This method returns the preferred README for a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/readme?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoReleases(owner, repo, callback)</td>
    <td style="padding:15px">Users with push access to the repository will receive all releases (i.e., published releases and draft releases). Users with pull access will receive published releases only</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoReleases(owner, repo, body, callback)</td>
    <td style="padding:15px">Create a release
Users with push access to the repository can create a release.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoReleasesAssetsId(owner, repo, id, callback)</td>
    <td style="padding:15px">Delete a release asset</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases/assets/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoReleasesAssetsId(owner, repo, id, callback)</td>
    <td style="padding:15px">Get a single release asset</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases/assets/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoReleasesAssetsId(owner, repo, id, body, callback)</td>
    <td style="padding:15px">Edit a release asset
Users with push access to the repository can edit a release asset.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases/assets/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoReleasesId(owner, repo, id, callback)</td>
    <td style="padding:15px">Users with push access to the repository can delete a release.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoReleasesId(owner, repo, id, callback)</td>
    <td style="padding:15px">Get a single release</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchReposOwnerRepoReleasesId(owner, repo, id, body, callback)</td>
    <td style="padding:15px">Users with push access to the repository can edit a release</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoReleasesIdAssets(owner, repo, id, callback)</td>
    <td style="padding:15px">List assets for a release</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/releases/{pathv3}/assets?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoStargazers(owner, repo, callback)</td>
    <td style="padding:15px">List Stargazers.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/stargazers?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoStatsCodeFrequency(owner, repo, callback)</td>
    <td style="padding:15px">Get the number of additions and deletions per week.
Returns a weekly aggregate of the number of additions and deletions pushed
to a repository.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/stats/code_frequency?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoStatsCommitActivity(owner, repo, callback)</td>
    <td style="padding:15px">Get the last year of commit activity data.
Returns the last year of commit activity grouped by week. The days array
is a group of commits per day, starting on Sunday.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/stats/commit_activity?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoStatsContributors(owner, repo, callback)</td>
    <td style="padding:15px">Get contributors list with additions, deletions, and commit counts.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/stats/contributors?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoStatsParticipation(owner, repo, callback)</td>
    <td style="padding:15px">Get the weekly commit count for the repo owner and everyone else.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/stats/participation?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoStatsPunchCard(owner, repo, callback)</td>
    <td style="padding:15px">Get the number of commits per hour in each day.
Each array contains the day number, hour number, and number of commits
0-6 Sunday - Saturday
0-23 Hour of day
Number of commits

For example, [2, 14, 25] indicates that there were 25 total commits, during
the 2.00pm hour on Tuesdays. All times are based on the time zone of
individual commits.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/stats/punch_card?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoStatusesRef(owner, repo, ref, callback)</td>
    <td style="padding:15px">List Statuses for a specific Ref.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/statuses/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postReposOwnerRepoStatusesRef(owner, repo, ref, body, callback)</td>
    <td style="padding:15px">Create a Status.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/statuses/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoSubscribers(owner, repo, callback)</td>
    <td style="padding:15px">List watchers.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/subscribers?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteReposOwnerRepoSubscription(owner, repo, callback)</td>
    <td style="padding:15px">Delete a Repository Subscription.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/subscription?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoSubscription(owner, repo, callback)</td>
    <td style="padding:15px">Get a Repository Subscription.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/subscription?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putReposOwnerRepoSubscription(owner, repo, body, callback)</td>
    <td style="padding:15px">Set a Repository Subscription</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/subscription?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoTags(owner, repo, callback)</td>
    <td style="padding:15px">Get list of tags.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/tags?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoTeams(owner, repo, callback)</td>
    <td style="padding:15px">Get list of teams</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/teams?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoWatchers(owner, repo, callback)</td>
    <td style="padding:15px">List Stargazers. New implementation.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/watchers?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getReposOwnerRepoArchiveFormatPath(owner, repo, archiveFormat = 'tarball', pathParam, callback)</td>
    <td style="padding:15px">Get archive link.
This method will return a 302 to a URL to download a tarball or zipball
archive for a repository. Please make sure your HTTP framework is
configured to follow redirects or you will need to use the Location header
to make a second GET request.
Note: For private repositories, these links are temporary and expire quickly.</td>
    <td style="padding:15px">{base_path}/{version}/repos/{pathv1}/{pathv2}/{pathv3}/{pathv4}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getRepositories(since, callback)</td>
    <td style="padding:15px">List all public repositories.
This provides a dump of every public repository, in the order that they
were created.
Note: Pagination is powered exclusively by the since parameter. is the
Link header to get the URL for the next page of repositories.</td>
    <td style="padding:15px">{base_path}/{version}/repositories?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSearchCodeWithOptions(queryData, callback)</td>
    <td style="padding:15px">Search code.</td>
    <td style="padding:15px">{base_path}/{version}/search/code?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSearchIssuesWithOptions(queryData, callback)</td>
    <td style="padding:15px">Find issues by state and keyword. (This method returns up to 100 results per page.)</td>
    <td style="padding:15px">{base_path}/{version}/search/issues?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSearchRepositories(order = 'desc', q, sort = 'stars', callback)</td>
    <td style="padding:15px">Search repositories.</td>
    <td style="padding:15px">{base_path}/{version}/search/repositories?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getSearchUsers(order = 'desc', q, sort = 'followers', callback)</td>
    <td style="padding:15px">Search users.</td>
    <td style="padding:15px">{base_path}/{version}/search/users?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteTeamsTeamId(teamId, callback)</td>
    <td style="padding:15px">Delete team.
In order to delete a team, the authenticated user must be an owner of the
org that the team is associated with.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getTeamsTeamId(teamId, callback)</td>
    <td style="padding:15px">Get team.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchTeamsTeamId(teamId, body, callback)</td>
    <td style="padding:15px">Edit team.
In order to edit a team, the authenticated user must be an owner of the org
that the team is associated with.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getTeamsTeamIdMembers(teamId, callback)</td>
    <td style="padding:15px">List team members.
In order to list members in a team, the authenticated user must be a member
of the team.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/members?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteTeamsTeamIdMembersUsername(teamId, username, callback)</td>
    <td style="padding:15px">The "Remove team member" API is deprecated and is scheduled for removal in the next major version of the API. We recommend using the Remove team membership API instead. It allows you to remove both active and pending memberships.

Remove team member.
In order to remove a user from a team, the authenticated user must have 'admin'
permissions to the team or be an owner of the org that the team is associated
with.
NOTE This does not delete the user, it just remove them from the team.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getTeamsTeamIdMembersUsername(teamId, username, callback)</td>
    <td style="padding:15px">The "Get team member" API is deprecated and is scheduled for removal in the next major version of the API. We recommend using the Get team membership API instead. It allows you to get both active and pending memberships.

Get team member.
In order to get if a user is a member of a team, the authenticated user mus
be a member of the team.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putTeamsTeamIdMembersUsername(teamId, username, callback)</td>
    <td style="padding:15px">The API (described below) is deprecated and is scheduled for removal in the next major version of the API. We recommend using the Add team membership API instead. It allows you to invite new organization members to your teams.

Add team member.
In order to add a user to a team, the authenticated user must have 'admin'
permissions to the team or be an owner of the org that the team is associated
with.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/members/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteTeamsTeamIdMembershipsUsername(teamId, username, callback)</td>
    <td style="padding:15px">Remove team membership.
In order to remove a membership between a user and a team, the authenticated user must have 'admin' permissions to the team or be an owner of the organization that the team is associated with. NOTE: This does not delete the user, it just removes their membership from the team.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/memberships/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getTeamsTeamIdMembershipsUsername(teamId, username, callback)</td>
    <td style="padding:15px">Get team membership.
In order to get a user's membership with a team, the authenticated user must be a member of the team or an owner of the team's organization.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/memberships/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putTeamsTeamIdMembershipsUsername(teamId, username, callback)</td>
    <td style="padding:15px">Add team membership.
In order to add a membership between a user and a team, the authenticated user must have 'admin' permissions to the team or be an owner of the organization that the team is associated with.

If the user is already a part of the team's organization (meaning they're on at least one other team in the organization), this endpoint will add the user to the team.

If the user is completely unaffiliated with the team's organization (meaning they're on none of the organization's team...(description truncated)</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/memberships/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getTeamsTeamIdRepos(teamId, callback)</td>
    <td style="padding:15px">List team repos</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/repos?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteTeamsTeamIdReposOwnerRepo(teamId, owner, repo, callback)</td>
    <td style="padding:15px">In order to remove a repository from a team, the authenticated user must be an owner of the org that the team is associated with. NOTE: This does not delete the repository, it just removes it from the team.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/repos/{pathv2}/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getTeamsTeamIdReposOwnerRepo(teamId, owner, repo, callback)</td>
    <td style="padding:15px">Check if a team manages a repository</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/repos/{pathv2}/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putTeamsTeamIdReposOwnerRepo(teamId, owner, repo, callback)</td>
    <td style="padding:15px">In order to add a repository to a team, the authenticated user must be an owner of the org that the team is associated with. Also, the repository must be owned by the organization, or a direct fork of a repository owned by the organization.</td>
    <td style="padding:15px">{base_path}/{version}/teams/{pathv1}/repos/{pathv2}/{pathv3}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUser(callback)</td>
    <td style="padding:15px">Get the authenticated user.</td>
    <td style="padding:15px">{base_path}/{version}/user?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">patchUser(body, callback)</td>
    <td style="padding:15px">Update the authenticated user.</td>
    <td style="padding:15px">{base_path}/{version}/user?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteUserEmails(body, callback)</td>
    <td style="padding:15px">Delete email address(es).
You can include a single email address or an array of addresses.</td>
    <td style="padding:15px">{base_path}/{version}/user/emails?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserEmails(callback)</td>
    <td style="padding:15px">List email addresses for a user.
In the final version of the API, this method will return an array of hashes
with extended information for each email address indicating if the address
has been verified and if it's primary email address for GitHub.
Until API v3 is finalized, use the application/vnd.github.v3 media type to
get other response format.</td>
    <td style="padding:15px">{base_path}/{version}/user/emails?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postUserEmails(body, callback)</td>
    <td style="padding:15px">Add email address(es).
You can post a single email address or an array of addresses.</td>
    <td style="padding:15px">{base_path}/{version}/user/emails?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserFollowers(callback)</td>
    <td style="padding:15px">List the authenticated user's followers</td>
    <td style="padding:15px">{base_path}/{version}/user/followers?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserFollowing(callback)</td>
    <td style="padding:15px">List who the authenticated user is following.</td>
    <td style="padding:15px">{base_path}/{version}/user/following?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteUserFollowingUsername(username, callback)</td>
    <td style="padding:15px">Unfollow a user.
Unfollowing a user requires the user to be logged in and authenticated with
basic auth or OAuth with the user:follow scope.</td>
    <td style="padding:15px">{base_path}/{version}/user/following/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserFollowingUsername(username, callback)</td>
    <td style="padding:15px">Check if you are following a user.</td>
    <td style="padding:15px">{base_path}/{version}/user/following/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putUserFollowingUsername(username, callback)</td>
    <td style="padding:15px">Follow a user.
Following a user requires the user to be logged in and authenticated with
basic auth or OAuth with the user:follow scope.</td>
    <td style="padding:15px">{base_path}/{version}/user/following/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserIssues(filter = 'assigned', state = 'open', labels, sort = 'created', direction = 'asc', since, callback)</td>
    <td style="padding:15px">List issues.
List all issues across owned and member repositories for the authenticated
user.</td>
    <td style="padding:15px">{base_path}/{version}/user/issues?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserKeys(callback)</td>
    <td style="padding:15px">List your public keys.
Lists the current user's keys. Management of public keys via the API requires
that you are authenticated through basic auth, or OAuth with the 'user', 'write:public_key' scopes.</td>
    <td style="padding:15px">{base_path}/{version}/user/keys?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postUserKeys(body, callback)</td>
    <td style="padding:15px">Create a public key.</td>
    <td style="padding:15px">{base_path}/{version}/user/keys?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteUserKeysKeyId(keyId, callback)</td>
    <td style="padding:15px">Delete a public key. Removes a public key. Requires that you are authenticated via Basic Auth or via OAuth with at least admin:public_key scope.</td>
    <td style="padding:15px">{base_path}/{version}/user/keys/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserKeysKeyId(keyId, callback)</td>
    <td style="padding:15px">Get a single public key.</td>
    <td style="padding:15px">{base_path}/{version}/user/keys/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserOrgs(callback)</td>
    <td style="padding:15px">List public and private organizations for the authenticated user.</td>
    <td style="padding:15px">{base_path}/{version}/user/orgs?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserRepos(type = 'all', callback)</td>
    <td style="padding:15px">List repositories for the authenticated user. Note that this does not include
repositories owned by organizations which the user can access. You can lis
user organizations and list organization repositories separately.</td>
    <td style="padding:15px">{base_path}/{version}/user/repos?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">postUserRepos(body, callback)</td>
    <td style="padding:15px">Create a new repository for the authenticated user. OAuth users must supply
repo scope.</td>
    <td style="padding:15px">{base_path}/{version}/user/repos?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserStarred(direction, sort = 'created', callback)</td>
    <td style="padding:15px">List repositories being starred by the authenticated user.</td>
    <td style="padding:15px">{base_path}/{version}/user/starred?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteUserStarredOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Unstar a repository</td>
    <td style="padding:15px">{base_path}/{version}/user/starred/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserStarredOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Check if you are starring a repository.</td>
    <td style="padding:15px">{base_path}/{version}/user/starred/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putUserStarredOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Star a repository.</td>
    <td style="padding:15px">{base_path}/{version}/user/starred/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserSubscriptions(callback)</td>
    <td style="padding:15px">List repositories being watched by the authenticated user.</td>
    <td style="padding:15px">{base_path}/{version}/user/subscriptions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">deleteUserSubscriptionsOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Stop watching a repository</td>
    <td style="padding:15px">{base_path}/{version}/user/subscriptions/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserSubscriptionsOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Check if you are watching a repository.</td>
    <td style="padding:15px">{base_path}/{version}/user/subscriptions/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">putUserSubscriptionsOwnerRepo(owner, repo, callback)</td>
    <td style="padding:15px">Watch a repository.</td>
    <td style="padding:15px">{base_path}/{version}/user/subscriptions/{pathv1}/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUserTeams(callback)</td>
    <td style="padding:15px">List all of the teams across all of the organizations to which the authenticated user belongs. This method requires user or repo scope when authenticating via OAuth.</td>
    <td style="padding:15px">{base_path}/{version}/user/teams?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsers(since, callback)</td>
    <td style="padding:15px">Get all users.
This provides a dump of every user, in the order that they signed up for GitHub.
Note: Pagination is powered exclusively by the since parameter. Use the Link
header to get the URL for the next page of users.</td>
    <td style="padding:15px">{base_path}/{version}/users?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsername(username, callback)</td>
    <td style="padding:15px">Get a single user.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameEvents(username, callback)</td>
    <td style="padding:15px">If you are authenticated as the given user, you will see your private events. Otherwise, you'll only see public events.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameEventsOrgsOrg(username, org, callback)</td>
    <td style="padding:15px">This is the user's organization dashboard. You must be authenticated as the user to view this.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/events/orgs/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameFollowers(username, callback)</td>
    <td style="padding:15px">List a user's followers</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/followers?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameFollowingTargetUser(username, targetUser, callback)</td>
    <td style="padding:15px">Check if one user follows another.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/following/{pathv2}?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameGists(username, since, callback)</td>
    <td style="padding:15px">List a users gists.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/gists?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameKeys(username, callback)</td>
    <td style="padding:15px">List public keys for a user.
Lists the verified public keys for a user. This is accessible by anyone.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/keys?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameOrgs(username, callback)</td>
    <td style="padding:15px">List all public organizations for a user.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/orgs?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameReceivedEvents(username, callback)</td>
    <td style="padding:15px">These are events that you'll only see public events.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/received_events?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameReceivedEventsPublic(username, callback)</td>
    <td style="padding:15px">List public events that a user has received</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/received_events/public?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameRepos(username, type = 'all', callback)</td>
    <td style="padding:15px">List public repositories for the specified user.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/repos?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameStarred(username, callback)</td>
    <td style="padding:15px">List repositories being starred by a user.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/starred?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
  <tr>
    <td style="padding:15px">getUsersUsernameSubscriptions(username, callback)</td>
    <td style="padding:15px">List repositories being watched by a user.</td>
    <td style="padding:15px">{base_path}/{version}/users/{pathv1}/subscriptions?{query}</td>
    <td style="padding:15px">Yes</td>
  </tr>
</table>
<br>
